﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;

public class GameManager : MonoBehaviour {

    public GameState gameState = GameState.MainMenu;
    public PlayerController player;
    public WaveGenerator waveGenerator;
    public SelfSetvisibleOff playerHint;

    public GameObject gameOverMenu;

    private float gameTime = 0f;
    public Text gameTimeText;

    public float delayTime = 4.8f;

    private bool mediumSet = true;
    private bool difficultSet = true;

	// Use this for initialization
	void Start () {
        if (player == null)
        {
            Debug.LogError("ERROR (GameManager): Falta enlazar el player");
        }
        if (waveGenerator == null)
        {
            Debug.LogError("ERROR (GameManager): Falta enlazar el wave manager");
        }
	}
	
	// Update is called once per frame
	void Update () {
        if (Input.GetButtonDown("Jump"))
        {
            if (gameState == GameState.Play && player != null)
            {
                player.Jump();
            }
        }
        //if (Input.GetButtonDown("Fire1"))
        //{
        //    if (gameState == GameState.Play && waveGenerator != null)
        //    {
        //        waveGenerator.GenerateWave();
        //    }
        //}
        if (gameTime > 20 && mediumSet)
        {
            SetPulsesBetweenWaves(6);
            mediumSet = false;
        }

        if (gameTime > 30 && difficultSet)
        {
            SetPulsesBetweenWaves(4);
            difficultSet = false;
        }

        if (gameState == GameState.Play)
        {
            gameTime += Time.deltaTime;
            if (gameTimeText != null)
            {
                gameTimeText.text = gameTime.ToString("F2");
            }
        }
	}

    public void StartGame()
    {
        if (gameState == GameState.MainMenu)
        {
            gameState = GameState.Play;

            if (gameTimeText != null)
            {
                gameTimeText.text = "0.00s";
                gameTime = 0f;
            }

            if (playerHint != null)
            {
                playerHint.gameObject.SetActive(true);
                playerHint.TurnOff();
            }

            Invoke("StartWaves", delayTime);
        }
    }

    public void StartWaves()
    {
        if (waveGenerator != null)
        {
            SetPulsesBetweenWaves(8);
            waveGenerator.StartGenerating();
        }
    }

    public void StopWaves()
    {
        if (waveGenerator != null)
        {
            waveGenerator.StopGenerating();
        }
    }

    public void SetPulsesBetweenWaves(int newValue)
    {
        if (waveGenerator != null)
        {
            waveGenerator.SetPulsesBetweenWaves(newValue);
        }
    }

    public void PauseGame()
    {
        if (gameState == GameState.Play)
        {
            gameState = GameState.Pause;
        }
    }

    public void UnpauseGame()
    {
        if (gameState == GameState.Pause)
        {
            gameState = GameState.Play;
        }
    }

    public void PlayerDies()
    {
        if (player != null)
        {
            player.gameObject.SetActive(false);
        }
        gameState = GameState.GameOver;
        if (gameOverMenu != null)
        {
            gameOverMenu.SetActive(true);
        }
    }
}

public enum GameState
{
    MainMenu,
    Play,
    Pause,
    GameOver
}
