﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class WaveGenerator : MonoBehaviour {

    public float waveHeight = 2.0f;
    public float waveTime = 1.0f;
    public float waveSpeed = 0.1f;

    public GameObject[] primaryWaves;
    public GameObject[] secondaryWaves;

    private Animator[] primaryAnimators;
    private Animator[] secondaryAnimators;

    private SingleWave[] primarySingleWaves;
    private SingleWave[] secondarySingleWaves;

    public ParticleSystem foam;

    private bool isGenerating = false;
    public float timeBetweenPulses = 0.5f;
    public float pulsesBetweenWaves = 4;
    private float currentWaveTime = 0f;
    private int currentPulses = 0;
    public bool mustGenerate = false;

	// Use this for initialization
	void Start () {
        primaryAnimators = new Animator[primaryWaves.Length];
        for (int i = 0; i < primaryWaves.Length; i++)
        {
            primaryAnimators[i] = primaryWaves[i].GetComponent<Animator>();
        }
        secondaryAnimators = new Animator[secondaryWaves.Length];
        for (int i = 0; i < secondaryWaves.Length; i++)
        {
            secondaryAnimators[i] = secondaryWaves[i].GetComponent<Animator>();
        }
        primarySingleWaves = new SingleWave[primaryWaves.Length];
        for (int i = 0; i < primaryWaves.Length; i++)
        {
            primarySingleWaves[i] = primaryWaves[i].GetComponentInChildren<SingleWave>();
        }
        secondarySingleWaves = new SingleWave[secondaryWaves.Length];
        for (int i = 0; i < secondaryWaves.Length; i++)
        {
            secondarySingleWaves[i] = secondaryWaves[i].GetComponentInChildren<SingleWave>();
        }
    }
	
	// Update is called once per frame
	void Update () {
        if (isGenerating)
        {
            if (mustGenerate)
            {
                GenerateWave();
                mustGenerate = false;
            }
        }
	}

    void FixedUpdate()
    {
        currentWaveTime += Time.deltaTime;
        if (currentWaveTime > timeBetweenPulses)
        {
            currentPulses++;
            currentWaveTime = 0f;
            if (currentPulses > pulsesBetweenWaves)
            {
                mustGenerate = true;
                currentPulses = 0;
            }
        }
    }

    public void SetPulsesBetweenWaves(int newValue)
    {
        currentPulses = 0;
        pulsesBetweenWaves = newValue;
    }

    public void StartGenerating()
    {
        isGenerating = true;
        currentPulses = 0;
        currentWaveTime = 0f;
    }

    public void StopGenerating()
    {
        isGenerating = false;
    }

    public void GenerateWave()
    {
        // Parar animaciones:
        //StopWaves(primaryAnimators);
        //StopWaves(secondaryAnimators);
        foreach (SingleWave item in primarySingleWaves)
        {
            if (item != null)
            {
                item.InitWave(this.waveTime, this.waveHeight, this.waveSpeed);
            }
        }
        foreach (SingleWave item in secondarySingleWaves)
        {
            if (item != null)
            {
                item.InitWave(this.waveTime, this.waveHeight / 2, this.waveSpeed);
            }
        }

        if (foam != null)
        {
            foam.Emit(40);
        }
    }

    private void StopWaves(Animator[] animators)
    {
        foreach (Animator item in animators)
        {
            //item.Stop();
            item.SetBool("playing", false);
        }
    }
}
